@@ -1,23 +1,11 @@
 /*
-   Copyright (C) 2006 by Peter Penz <peter.penz@gmx.at>
-   Copyright (C) 2006 by Dominic Battre <dominic@battre.de>
-   Copyright (C) 2006 by Martin Pool <mbp@canonical.com>
+    SPDX-FileCopyrightText: 2006 Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2006 Dominic Battre <dominic@battre.de>
+    SPDX-FileCopyrightText: 2006 Martin Pool <mbp@canonical.com>
 
-   Separated from Dolphin by Nick Shaforostoff <shafff@ukr.net>
+    Separated from Dolphin by Nick Shaforostoff <shafff@ukr.net>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KDIRSORTFILTERPROXYMODEL_H
@@ -25,10 +13,12 @@
 
 #include <QFileInfo>
 
-#include <kcategorizedsortfilterproxymodel.h>
+#include <KCategorizedSortFilterProxyModel>
 
 #include "kiofilewidgets_export.h"
 
+#include <memory>
+
 /**
  * @class KDirSortFilterProxyModel kdirsortfilterproxymodel.h <KDirSortFilterProxyModel>
  *
@@ -49,8 +39,7 @@
  *
  * @author Dominic Battre, Martin Pool and Peter Penz
  */
-class KIOFILEWIDGETS_EXPORT KDirSortFilterProxyModel
-    : public KCategorizedSortFilterProxyModel
+class KIOFILEWIDGETS_EXPORT KDirSortFilterProxyModel : public KCategorizedSortFilterProxyModel
 {
     Q_OBJECT
 
@@ -85,20 +74,27 @@ public:
      */
     bool sortFoldersFirst() const;
 
+    /**
+     * Sets a separate sorting with hidden files and folders last (true) or not (false).
+     * @since 5.95
+     */
+    void setSortHiddenFilesLast(bool hiddenFilesLast);
+    bool sortHiddenFilesLast() const;
+
     Qt::DropActions supportedDragOptions() const;
 
 protected:
     /**
      * Reimplemented from KCategorizedSortFilterProxyModel.
      */
-    virtual bool subSortLessThan(const QModelIndex &left,
-                                 const QModelIndex &right) const override;
+    virtual bool subSortLessThan(const QModelIndex &left, const QModelIndex &right) const override;
+
 private:
     Q_PRIVATE_SLOT(d, void slotNaturalSortingChanged())
 
 private:
     class KDirSortFilterProxyModelPrivate;
-    KDirSortFilterProxyModelPrivate *const d;
+    std::unique_ptr<KDirSortFilterProxyModelPrivate> const d;
 };
 
 #endif
