@@ -215,9 +215,7 @@ void AccessManagerReply::setHeaderFromMetaData(const KIO::MetaData &_metaData)
                 continue;
             }
 
-            const QStringRef headerName = httpHeader.leftRef(index);
-            QString headerValue = httpHeader.mid(index + 1);
-
+            const auto headerName = QStringView(httpHeader).left(index);
             // Ignore cookie header since it is handled by the http ioslave.
             if (headerName.startsWith(QLatin1String("set-cookie"), Qt::CaseInsensitive)) {
                 continue;
@@ -227,6 +225,7 @@ void AccessManagerReply::setHeaderFromMetaData(const KIO::MetaData &_metaData)
                 continue;
             }
 
+            QString headerValue = httpHeader.mid(index + 1);
             // Without overriding the corrected mime-type sent by kio_http, add
             // back the "charset=" portion of the content-type header if present.
             if (headerName.startsWith(QLatin1String("content-type"), Qt::CaseInsensitive)) {
@@ -260,7 +259,7 @@ void AccessManagerReply::setHeaderFromMetaData(const KIO::MetaData &_metaData)
     }
 
     // Set the returned meta data as attribute...
-    setAttribute(static_cast<QNetworkRequest::Attribute>(KIO::AccessManager::MetaData), metaData.toVariant());
+    setAttribute(static_cast<QNetworkRequest::Attribute>(KIO::Integration::AccessManager::MetaData), metaData.toVariant());
 }
 
 void AccessManagerReply::setIgnoreContentDisposition(bool on)
@@ -279,7 +278,6 @@ void AccessManagerReply::putOnHold()
     m_kioJob.data()->disconnect(this);
     m_kioJob.data()->putOnHold();
     m_kioJob.clear();
-    KIO::Scheduler::publishSlaveOnHold();
 }
 
 bool AccessManagerReply::isLocalRequest(const QUrl &url)
@@ -316,7 +314,7 @@ int AccessManagerReply::jobError(KJob *kJob)
     switch (errCode) {
     case 0:
         break; // No error;
-    case KIO::ERR_SLAVE_DEFINED:
+    case KIO::ERR_WORKER_DEFINED:
     case KIO::ERR_NO_CONTENT: // Sent by a 204 response is not an error condition.
         setError(QNetworkReply::NoError, kJob->errorText());
         break;
@@ -418,7 +416,7 @@ void AccessManagerReply::slotResult(KJob *kJob)
 
     const QUrl redirectUrl = attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
     if (!redirectUrl.isValid()) {
-        setAttribute(static_cast<QNetworkRequest::Attribute>(KIO::AccessManager::KioError), errcode);
+        setAttribute(static_cast<QNetworkRequest::Attribute>(KIO::Integration::AccessManager::KioError), errcode);
         if (errcode && errcode != KIO::ERR_NO_CONTENT) {
             const auto networkError = error();
             Q_EMIT errorOccurred(networkError);
